==> agda_2.6.3.orig.tar.gz: Agda-2.6.3/README.md <==
Agda 2
======

[![Hackage version](https://img.shields.io/hackage/v/Agda.svg?label=Hackage)](http://hackage.haskell.org/package/Agda)
[![Stackage version](https://www.stackage.org/package/Agda/badge/lts?label=Stackage)](https://www.stackage.org/package/Agda)
[![Test](https://github.com/agda/agda/workflows/Build,%20Test,%20and%20Benchmark/badge.svg?branch=master)](https://github.com/agda/agda/actions?query=workflow%3A%22Build%2C+Test%2C+and+Benchmark%22)
[![Stack Build Status via GH Actions](https://github.com/agda/agda/workflows/stack%20build/badge.svg)](https://github.com/agda/agda/actions?query=workflow%3A%22stack+build%22)
[![Documentation Status](https://readthedocs.org/projects/agda/badge/?version=latest)](http://agda.readthedocs.io/en/latest/?badge=latest)
[![Agda Zulip](https://img.shields.io/badge/zulip-join_chat-brightgreen.svg)](https://agda.zulipchat.com)

![The official Agda logo](doc/user-manual/agda.svg)

Note that this README is only about Agda, not its standard
library. See the [Agda Wiki][agdawiki] for information about the
library.

Documentation
-------------

* [User manual](http://agda.readthedocs.io)
  (per-commit pdf can be downloaded from the
  [github actions](https://github.com/agda/agda/actions?query=workflow%3A%22User+Manual%22) page)
* [CHANGELOG](https://github.com/agda/agda/blob/master/CHANGELOG.md)

Getting Started
----------------

* [Installation](https://agda.readthedocs.io/en/latest/getting-started/installation.html)
* [Quick guide to editing, type checking and compiling Agda
  code](https://agda.readthedocs.io/en/latest/getting-started/a-taste-of-agda.html)

Contributing to Agda
--------------------

* Contribution how-to: [`HACKING`](https://github.com/agda/agda/blob/master/HACKING.md)
* [Haskell style-guide](https://github.com/andreasabel/haskell-style-guide/blob/master/haskell-style.md)

[agdawiki]: http://wiki.portal.chalmers.se/agda/pmwiki.php

==> agda_2.6.4.3.orig.tar.gz: Agda-2.6.4.3/README.md <==
Agda 2
======

[![Hackage version](https://img.shields.io/hackage/v/Agda.svg?label=Hackage)](http://hackage.haskell.org/package/Agda)
[![Stackage version](https://www.stackage.org/package/Agda/badge/lts?label=Stackage)](https://www.stackage.org/package/Agda)
[![Test](https://github.com/agda/agda/workflows/Build,%20Test,%20and%20Benchmark/badge.svg?branch=master)](https://github.com/agda/agda/actions?query=workflow%3A%22Build%2C+Test%2C+and+Benchmark%22)
[![Documentation Status](https://readthedocs.org/projects/agda/badge/?version=latest)](http://agda.readthedocs.io/en/latest/?badge=latest)
[![Agda Zulip](https://img.shields.io/badge/zulip-join_chat-brightgreen.svg)](https://agda.zulipchat.com)

![The official Agda logo](doc/user-manual/agda.svg)

Note that this README is only about Agda, not its standard
library. See the [Agda Wiki][agdawiki] for information about the
library.

Documentation
-------------

* [User manual](http://agda.readthedocs.io)
  (per-commit pdf can be downloaded from the
  [github actions](https://github.com/agda/agda/actions/workflows/user_manual.yml) page)
* [CHANGELOG](https://github.com/agda/agda/blob/master/CHANGELOG.md)

Getting Started
----------------

* [Installation](https://agda.readthedocs.io/en/latest/getting-started/installation.html)
* [Quick guide to editing, type checking and compiling Agda
  code](https://agda.readthedocs.io/en/latest/getting-started/a-taste-of-agda.html)

Contributing to Agda
--------------------

* Contribution how-to: [`HACKING`](https://github.com/agda/agda/blob/master/HACKING.md)
* [Haskell style-guide](https://github.com/andreasabel/haskell-style-guide/blob/master/haskell-style.md)

[agdawiki]: http://wiki.portal.chalmers.se/agda/pmwiki.php
